@@ -16,8 +16,14 @@ class SynologyFileCache():
         warnings.simplefilter('ignore', ResourceWarning)
         self.cache_path_root = cache_path_root
         self.namespace = namespace
-        self.fl = filestation.FileStation(ip_address=ip_address, port=port, username=username,
-                                          password=password)
+        self.ip_address = ip_address
+        self.port = port
+        self.username = username
+        self.password = password
+
+    def getFl(self):
+        return filestation.FileStation(ip_address=self.ip_address, port=self.port, username=self.username,
+                                       password=self.password)
 
     def random_str(self, num):
         salt = ''.join(random.sample(string.ascii_letters + string.digits, num))
@@ -30,7 +36,7 @@ class SynologyFileCache():
 
     def _exist(self, file_path):
         try:
-            res = self.fl.get_file_info(file_path)
+            res = self.getFl().get_file_info(file_path)
             if res['data']['files'][0]['code'] == 408:
                 return False
             elif res['data']['files'][0]['name']:
@@ -41,7 +47,7 @@ class SynologyFileCache():
     def create_folder(self, folder_path):
         basename = os.path.basename(folder_path)
         dirname = os.path.dirname(folder_path)
-        self.fl.create_folder(folder_path=dirname, name=basename)
+        self.getFl().create_folder(folder_path=dirname, name=basename)
 
     def set(self, key, file_path, del_local=True):
         """
@@ -69,7 +75,7 @@ class SynologyFileCache():
             elif os.path.isfile(file_path):
                 new_file_path = os.path.join(os.path.dirname(file_path), key)
                 local_path = new_file_path
-            res = self.fl.upload_file(dest_path=cache_path, file_path=local_path)
+            res = self.getFl().upload_file(dest_path=cache_path, file_path=local_path)
             logging.info(res)
             if del_local:
                 if os.path.exists(local_path):
@@ -85,7 +91,7 @@ class SynologyFileCache():
         local_file_dirname = os.path.dirname(local_file)
 
         try:
-            self.fl.get_file(path=cache_path, mode='download', dest_path=local_file_dirname)
+            self.getFl().get_file(path=cache_path, mode='download', dest_path=local_file_dirname)
             local_file_hash_name = os.path.join(local_file_dirname, key)
             if os.path.exists(local_file_hash_name):
                 os.rename(local_file_hash_name, local_file)
@@ -102,7 +108,7 @@ class SynologyFileCache():
         cache_path = "%s/%s/%s" % (self.cache_path_root, self.namespace, key)
 
         try:
-            return self.fl.delete_blocking_function(path=cache_path)
+            return self.getFl().delete_blocking_function(path=cache_path)
         except:
             return False
 
